<?php

class ThumbSniper_Options
{
	const THUMBSNIPER_VERSION = "1002";

	private $pagehook_general;
	private $general_settings_defaults = array();
	private $general_settings;



	function ThumbSniper_Options() 
	{
		$this->__construct();
	} // function



	function __construct()
	{
		$this->set_general_settings_defaults( "thumbsniper_preview", "external" );
		$this->set_general_settings_defaults( "thumbsniper_showfooter", "yes" );
		$this->set_general_settings_defaults( "thumbsniper_scaling", "4" );
		$this->set_general_settings_defaults( "thumbsniper_include_pages", "" );
		$this->set_general_settings_defaults( "thumbsniper_exclude_urls", "" );
		$this->set_general_settings_defaults( "thumbsniper_background", "youtube" );
		$this->set_general_settings_defaults( "thumbsniper_wp_jquery", "yes" );
		$this->set_general_settings_defaults( "thumbsniper_jquery_noconflict", "no" );
		$this->set_general_settings_defaults( "thumbsniper_qtip_footer", "yes" );
		$this->set_general_settings_defaults( "thumbsniper_position", "below" );
		$this->set_general_settings_defaults( "thumbsniper_variant", "1" );

		$this->plugin_update();

		add_filter(
			$tag = 'screen_layout_columns',
			$function_to_add = array( &$this, 'on_screen_layout_columns' ),
			$priority = 10,
			$accepted_args = 2
			);

		add_action(
			$tag = 'save_post',
			$function_to_add = array( &$this, 'thumbsniper_hide_save' ),
			$priority = null,
			$accepted_args = 1
			);

                add_action(
                        $tag = 'admin_menu',
                        $function_to_add = array( &$this, 'admin_init_menu' ),
                        $priority = null,
                        $accepted_args = null
                        );

		add_action(
			$tag = 'admin_init',
			$function_to_add = array( &$this, 'admin_init' ),
			$priority = null,
			$accepted_args = null
			);
	} // function



	function plugin_update() 
	{
		$version = get_option('thumbsniper');

		if($version != false) 
		{
			if($version != self::THUMBSNIPER_VERSION)
			{
				update_option('thumbsniper', self::THUMBSNIPER_VERSION);
			}
			return true;
		}

		//general options
		$go = array();

		$thumbsniper_preview = get_option('thumbsniper_preview');
		$thumbsniper_preview_default = $this->get_general_settings_defaults('thumbsniper_preview');
		if(!empty($thumbsniper_preview) && $thumbsniper_preview != $thumbsniper_preview_default) 
		{
			$go['thumbsniper_preview'] = $thumbsniper_preview;
		}

		$thumbsniper_scaling = get_option('thumbsniper_scaling');
		$thumbsniper_scaling_default = $this->get_general_settings_defaults('thumbsniper_scaling');
		if(!empty($thumbsniper_scaling) && $thumbsniper_scaling != $thumbsniper_scaling_default) 
		{
			$go['thumbsniper_scaling'] = $thumbsniper_scaling;
		}

		$thumbsniper_exclude_urls = get_option('thumbsniper_excluded_urls');
		if(!empty($thumbsniper_exclude_urls)) 
		{
			$oldurls = preg_split("/\;/", $thumbsniper_exclude_urls);
			$newurls = array();

			foreach($oldurls as $key => $value) 
			{
				$newurls[] = $value . "*";
			}

			$go['thumbsniper_exclude_urls'] = $newurls;
		}

		$thumbsniper_background = get_option('thumbsniper_bgcolor');
		$thumbsniper_background_default = $this->get_general_settings_defaults('thumbsniper_background');
		if(!empty($thumbsniper_background) && $thumbsniper_background != $thumbsniper_background_default) 
		{
			$go['thumbsniper_background'] = $thumbsniper_background;
		}

		if(!empty($go)) 
		{
			update_option('thumbsniper_general_settings', $go);
		}

		delete_option('thumbsniper_version');
		delete_option('thumbsniper_preview');
		delete_option('thumbsniper_showfooter');
		delete_option('thumbsniper_scaling');
		delete_option('thumbsniper_opacity');
		delete_option('thumbsniper_code_placement');
		delete_option('thumbsniper_excluded_urls');
		delete_option('thumbsniper_bgcolor');
		delete_option('thumbsniper_include_pages');

		return true;
	} // function



	function get_general_setting($arg)
	{
		if($this->general_settings == false) {
			$this->general_settings = wp_parse_args(get_option('thumbsniper_general_settings'), $this->general_settings_defaults);
		}

		return $this->general_settings[$arg];
	} // function



	function admin_init_menu()
	{
		//ensure, that the needed javascripts been loaded to allow drag/drop, expand/collapse and hide/show of boxes
		wp_enqueue_script('common');
		wp_enqueue_script('wp-lists');
		wp_enqueue_script('postbox');

		$this->pagehook_general = add_menu_page(
			$page_title = "ThumbSniper",
			$menu_title = "ThumbSniper",
			$capability = 'manage_options',
			$menu_slug = 'thumbsniper',
			$function = array( &$this, 'general_settings_page' ),
			$icon_url = null,
			$position = null
			);

		add_submenu_page(
			$parent_slug = 'thumbsniper',
			$page_title = __('General settings', 'thumbsniper'),
			$menu_title = __('General settings', 'thumbsniper'),
			$capability = 'manage_options',
			$menu_slug = 'thumbsniper',
			$function = null
			);

		$current_user_role = thumbsniper_get_current_user_role();

		if( $current_user_role ==  "Administrator" || $current_user_role ==  "Editor" )
		{
			add_meta_box(
				$id = 'thumbsniper_hide',
				$title = 'ThumbSniper',
				$callback = array( &$this, 'thumbsniper_hide' ),
				$post_type = 'page',
				$context = 'advanced', 
				$priority = 'default'
				);

			add_meta_box(
				$id = 'thumbsniper_hide',
				$title = 'ThumbSniper',
				$callback = array( &$this, 'thumbsniper_hide' ),
				$post_type = 'post',
				$context = 'advanced',
				$priority = 'default'
				);
		}

		add_meta_box(
			$id = 'thumbsniper_misc',
			$title = __('Misc', 'thumbsniper'),
			$callback = array( &$this, 'general_settings_misc' ),
			$post_type = $this->pagehook_general,
			$context = 'normal',
			$priority = 'low'
		);

		add_meta_box(
			$id = 'thumbsniper_targets',
			$title = __('Targets', 'thumbsniper'),
			$callback = array( &$this, 'general_settings_targets' ),
			$post_type = $this->pagehook_general,
			$context = 'normal',
			$priority = 'core'
		);

		add_meta_box(
			$id = 'thumbsniper_styling',
			$title = __('Styling', 'thumbsniper'),
			$callback = array( &$this, 'general_settings_styling' ),
			$post_type = $this->pagehook_general,
			$context = 'normal',
			$priority = 'core'
		);

		add_meta_box(
			$id = 'thumbsniper_compatibility',
			$title = __('Compatibility', 'thumbsniper'),
			$callback = array( &$this, 'general_settings_compatibility' ),
			$post_type = $this->pagehook_general,
			$context = 'normal',
			$priority = 'core'
		);

		add_meta_box(
			$id = 'thumbsniper_info',
			$title = __('Info', 'thumbsniper'),
			$callback = array( &$this, 'general_info_meta_box' ),
			$post_type = $this->pagehook_general,
			$context = 'side',
			$priority = 'core'
		);
	} // function



	function admin_init()
	{
		register_setting(
			$option_group = 'thumbsniper_general_settings',
			$option_name = 'thumbsniper_general_settings',
			$sanitize_callback = array( &$this, 'general_settings_validate' )
			);

		add_settings_field(
			$id = 'thumbsniper_preview',
			$title = 'preview type',
			$callback = array( &$this, 'dummy' ),
			$page = 'thumbsniper', 
			$section = null,
			$args = null
			);

		add_settings_field(
			$id = 'thumbsniper_exclude_urls',
			$title = 'excluded URL\'s',
			$callback = array( &$this, 'dummy' ),
			$page = 'thumbsniper',
			$section = null,
			$args = null
			);

		add_settings_field(
			$id = 'thumbsniper_include_pages',
			$title = 'include pages',
			$callback = array( &$this, 'dummy' ),
			$page = 'thumbsniper',
			$section = null,
			$args = null
			);

		add_settings_field(
			$id = 'thumbsniper_scaling',
			$title = 'image size',
			$callback = array( &$this, 'dummy' ),
			$page = 'thumbsniper',
			$section = null,
			$args = null
			);

		add_settings_field(
			$id = 'thumbsniper_background',
			$title = 'background',
			$callback = array( &$this, 'dummy' ),
			$page = 'thumbsniper',
			$section = null,
			$args = null
			);

		add_settings_field(
			$id = 'thumbsniper_position',
			$title = 'position',
			$callback = array( &$this, 'dummy' ),
			$page = 'thumbsniper',
			$section = null,
			$args = null
			);

		add_settings_field(
			$id = 'thumbsniper_wp_jquery',
			$title = 'use default wordpress jquery',
			$callback = array( &$this, 'dummy' ),
			$page = 'thumbsniper',
			$section = null,
			$args = null
			);

		add_settings_field(
			$id = 'thumbsniper_jquery_noconflict',
			$title = 'use jquery\'s noConflict mode',
			$callback = array( &$this, 'dummy' ),
			$page = 'thumbsniper',
			$section = null,
			$args = null
			);

                add_settings_field(
                        $id = 'thumbsniper_qtip_footer',
                        $title = 'load qTip-library in page footer',
                        $callback = array( &$this, 'dummy' ),
                        $page = 'thumbsniper',
                        $section = null,
                        $args = null
                        );

		add_settings_field(
			$id = 'thumbsniper_showfooter',
			$title = 'show footer', 
			$callback = array( &$this, 'dummy' ),
			$page = 'thumbsniper',
			$section = null,
			$args = null
			);

		add_settings_field(
			$id = 'thumbsniper_variant',
			$title = 'thumbnail variant',
			$callback = array( &$this, 'dummy' ),
			$page = 'thumbsniper',
			$section = null,
			$args = null
			);
	} // function



	function on_screen_layout_columns( $columns, $screen )
	{
		//if( !defined( 'WP_NETWORK_ADMIN' ) && !defined( 'WP_USER_ADMIN' ) )
		//{
			if( $screen == $this->pagehook_general )
			{
				$columns[$this->pagehook_general] = 2;
			} // if
		//} // if

		return $columns;
	} // function



	function thumbsniper_hide()
	{
		global $post;
		$thumbsniper_hide = get_post_meta($post->ID, 'thumbsniper_hide', true);

		if( isset( $thumbsniper_hide ) && $thumbsniper_hide == 1 )
		{
			$thumbsniper_hide = ' checked="checked"';
		}
		else
		{
			$thumbsniper_hide = '';
		}
?>

		<p><label for="thumbsniper_hide">
		<input name="thumbsniper_hide" id="thumbsniper_hide" value="1" <?php echo $thumbsniper_hide; ?> type="checkbox"> <?php _e('Disable ThumbSniper on this page.', 'thumbsniper'); ?>
		</label></p>

<?php
	}



	function thumbsniper_hide_save( $post_id )
	{
		if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE)
		{
			return $post_id;
		}

		if( $_POST['post_type'] == "post" || $_POST['post_type'] == "page" )
		{
			if( current_user_can( 'edit_post', $post_id ) )
			{
				if( isset( $_POST['thumbsniper_hide'] ) )
				{
					update_post_meta( $post_id, 'thumbsniper_hide', 1 );
				}
				else
				{
					delete_post_meta( $post_id, 'thumbsniper_hide' );
				}
			}
		}

		return $post_id;
	}




	function general_settings_js_scaling_options() 
	{
?>

		<script type="text/javascript">
		//<![CDATA[

			function thumbsniper_set_scaling_options(variant, selected)
			{
				var scaling_select = document.getElementById("thumbsniper_scaling");

				if(!selected)
				{
					if(scaling_select.options[scaling_select.selectedIndex] != undefined)
					{
						selected = scaling_select.options[scaling_select.selectedIndex].value;
					}
				}

				scaling_select.options.length = 0;
				if(variant == 0)
				{
					document.getElementById("thumbsniper_scaling_default").innerHTML = "182 x 137";
					scaling_select.options[0]                     = new Option("91 x 68", "8", false,   selected == 8 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("104 x 78", "7", false,  selected == 7 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("121 x 91", "6", false,  selected == 6 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("146 x 110", "5", false, selected == 5 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("182 x 137", "4", false, selected == 4 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("242 x 182", "3", false, selected == 3 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("365 x 274", "2", false, selected == 2 ? true : false);
				}else if(variant == 1)
				{
					document.getElementById("thumbsniper_scaling_default").innerHTML = "182 x 230";
					scaling_select.options[0]                     = new Option("91 x 115", "8", false,  selected == 8 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("104 x 131", "7", false, selected == 7 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("121 x 153", "6", false, selected == 6 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("146 x 184", "5", false, selected == 5 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("182 x 230", "4", false, selected == 4 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("242 x 306", "3", false, selected == 3 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("365 x 461", "2", false, selected == 2 ? true : false);
				}else if(variant == 2)
				{
					document.getElementById("thumbsniper_scaling_default").innerHTML = "182 x 230";
					scaling_select.options[0]                     = new Option("91 x 115", "8", false,  selected == 8 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("104 x 131", "7", false, selected == 7 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("121 x 153", "6", false, selected == 6 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("146 x 184", "5", false, selected == 5 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("182 x 230", "4", false, selected == 4 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("242 x 306", "3", false, selected == 3 ? true : false);
					scaling_select.options[scaling_select.length] = new Option("365 x 461", "2", false, selected == 2 ? true : false);
				}
			} //function

		//]]>
		</script>

<?php
	} // function



	function general_settings_page()
	{
		$this->general_settings_js_scaling_options();
?>

		<script type="text/javascript">
		//<![CDATA[

			jQuery(document).ready( function($) 
			{
				thumbsniper_set_scaling_options("<?php echo $this->get_general_setting("thumbsniper_variant"); ?>", <?php echo $this->get_general_setting("thumbsniper_scaling"); ?>);

				// close postboxes that should be closed
				$('.if-js-closed').removeClass('if-js-closed').addClass('closed');
				// postboxes setup
				postboxes.add_postbox_toggles('<?php echo $this->pagehook_general; ?>');
			});

		//]]>
		</script>

		<div class="wrap">
			<h2>ThumbSniper - <?php _e('General settings', 'thumbsniper'); ?></h2>
			<form action="options.php" method="post">
				<div id="poststuff" class="metabox-holder has-right-sidebar">
					<div id="side-info-column" class="inner-sidebar">
						<?php do_meta_boxes($this->pagehook_general, 'side', null); ?>
					</div>
					<div id="post-body" class="has-sidebar">
						<div id="post-body-content" class="has-sidebar-content">
							<?php do_meta_boxes($this->pagehook_general, 'normal', NULL); ?>
							<?php do_settings_sections('thumbsniper'); ?>
							<?php settings_fields('thumbsniper_general_settings'); ?>
							<input name="Submit" type="submit" value="<?php esc_attr_e('Save Changes'); ?>" />
							<?php wp_nonce_field('closedpostboxes', 'closedpostboxesnonce', false ); ?>
							<?php wp_nonce_field('meta-box-order', 'meta-box-order-nonce', false ); ?>
						</div>
					</div>
				</div>
			</form>
		</div>

<?php
	} // function



	function general_settings_misc() 
	{
?>

		<p><?php _e('Providing you and your visitors with the freshest thumbnails takes a lot of server resources which isn&#39;t free of charge for me. I&#39;m providing these resources at no cost, because that&#39;s my hobby and I like running servers at a high load.', 'thumbsniper'); ?></p>
		<p><strong><?php _e('Instead of demanding a fee, I would be glad if you would spend me a backlink on your site.', 'thumbsniper'); ?></strong></p>
		<p><?php _e('You may either use the automatic footer link or place a hyperlink somewhere else on your site which should be like that', 'thumbsniper'); ?>:<br>
			<pre><code>&lt;a href="http://thumbsniper.com" title="ThumbSniper" target="_blank"&gt;ThumbSniper&lt;/a&gt;</code></pre>
		</p><br/>

<?php

		echo '<table width="100%">';
		$this->thumbsniper_showfooter();
		echo '</table>';

	} // function



	function general_settings_targets()
	{
?>

		<ol>
			<li><?php _e('Tooltips can be used for three types of hyperlinks. &quot;All&quot; just means all links that exist on a page and &quot;external&quot; hides the thumbshots for internal links. Using the option value &quot;marked&quot; means, that the tooltip-thumbshots are only shown if a link has a style class named &quot;thumbsniper&quot;.', 'thumbsniper'); ?></li>
			<li><?php _e('You may additionally use the CSS class &quot;nothumbsniper&quot; to explicitly disable the preview tooltip for single hyperlinks when using the preview types &quot;all&quot; or &quot;external&quot;.', 'thumbsniper'); ?></li>
			<li><?php _e('While in &quot;external&quot; or &quot;all&quot; mode, you can limit the plugin to explicitly defined numeric page id&#39;s (comma-separated) with the option &quot;include pages&quot;. Just leave it empty to ignore this feature.', 'thumbsniper'); ?></li>
			<li><?php _e('Use the &quot;excluded URLs&quot; option to define (yes, you guessed it already) excluded URLs. These URLs have to be entered as one per line. It works only with the preview types &quot;all&quot; or &quot;external&quot; and follows the basic rules for JavaScript regular expressions. Like this:', 'thumbsniper'); ?><br>
			<pre>http://www.foobar.com/somepath/.*<br>http://www.foobar.com/somepath.*.pdf<br>http://.*.foobar.com/</pre><?php _e('Please tell me about your results with it.', 'thumbsniper'); ?></li>
			<li><?php _e('While editing posts or pages you can use the &quot;Disable ThumbSniper on this page&quot; checkbox to exclude internal single posts or pages.', 'thumbsniper'); ?></li>
		</ol>
		<br>
		<table width="100%">
			<?php $this->thumbsniper_preview(); ?>
			<?php $this->thumbsniper_excluded_urls(); ?>
			<?php $this->thumbsniper_include_pages(); ?>
		</table>

<?php
	} // function



	function general_settings_styling()
	{
		echo '<table width="100%">';
		$this->thumbsniper_variant();
		$this->thumbsniper_scaling();
		$this->thumbsniper_background();
		$this->thumbsniper_position();
		echo "</table>";
	}



	function general_settings_compatibility() 
	{
?>

		<p><?php _e('If you experience a problem or a javascript error/conflict while using this plugin, just try to toggle one or more of these options:', 'thumbsniper'); ?></p>
		<br/>
		<table width="100%">
		<?php $this->thumbsniper_wp_jquery(); ?>
		<?php $this->thumbsniper_jquery_noconflict(); ?>
		<?php $this->thumbsniper_qtip_footer(); ?>
		</table>

<?php
	}



	function general_info_meta_box()
	{
?>

		<p><?php _e('Your feedback should go here:', 'thumbsniper'); ?>
                        <a href="http://thumbsniper.com/project-feedback/" target="_blank">http://thumbsniper.com/project-feedback/</a>
                </p>
                <p><strong><?php _e('Thank you very much!', 'thumbsniper'); ?></strong></p>
<?php
	}



	function thumbsniper_preview() 
	{
		$option = $this->get_general_setting('thumbsniper_preview');
?>

		<tr>
			<td>
				<label for="thumbsniper_general_settings[thumbsniper_preview]">
					<?php echo __("Preview type", "thumbsniper"); ?>
				</label>
			</td>
			<td>
				<select id="thumbsniper_preview" name="thumbsniper_general_settings[thumbsniper_preview]">
					<option value="all"<?php if( $option == 'all' ) echo( ' selected=selected' ); ?>><?php _e('all', 'thumbsniper'); ?></option>
					<option value="external"<?php if( $option == 'external' ) echo( ' selected=selected' ); ?>><?php _e('external', 'thumbsniper'); ?></option>
					<option value="marked"<?php if( $option == 'marked' ) echo( ' selected=selected' ); ?>><?php _e('marked', 'thumbsniper'); ?></option>
				</select> (<?php _e('default', 'thumbsniper'); ?>: <?php _e($this->general_settings_defaults['thumbsniper_preview'], 'thumbsniper'); ?>)
			</td>
		</tr>

<?php
	}



	function thumbsniper_excluded_urls()
	{
		$option = $this->get_general_setting('thumbsniper_exclude_urls');
?>

		<tr>
			<td>
				<label for="thumbsniper_general_settings[thumbsniper_exclude_urls]">
					<?php echo __("Excluded URLs", "thumbsniper"); ?>
				</label>
			</td>
			<td>
				<textarea id="thumbsniper_exclude_urls" name="thumbsniper_general_settings[thumbsniper_exclude_urls]" rows="6" class="large-text code"><?php foreach($option as $value) { echo(esc_textarea($value) . "\n"); } ?></textarea>
			</td>
		</tr>

<?php
	
	}



	function thumbsniper_include_pages()
	{
		$option = $this->get_general_setting('thumbsniper_include_pages');
?>

		<tr>
			<td>
				<label for="thumbsniper_general_settings[thumbsniper_include_pages]">
					<?php echo __("Include pages", "thumbsniper"); ?>
				</label>
			</td>
			<td>
				<input type="text" name="thumbsniper_general_settings[thumbsniper_include_pages]" value="<?php 
					foreach( $this->get_general_setting("thumbsniper_include_pages") as $pageId )
					{
						echo $pageId . ",";
					} ?>" class="large-text" />
			</td>
		</tr>

<?php
	}



	function thumbsniper_scaling()
	{
		$option = $this->get_general_setting('thumbsniper_scaling');
?>

		<tr>
			<td>
				<label for="thumbsniper_general_settings[thumbsniper_scaling]">
					<?php echo __("image size", "thumbsniper"); ?>
				</label>
			</td>
			<td>
				<select id="thumbsniper_scaling" name="thumbsniper_general_settings[thumbsniper_scaling]" onload="thumbsniper_set_scaling_options(<?php echo $this->get_general_setting("thumbsniper_variant"); ?>);">
        			</select> (<?php _e('default', 'thumbsniper'); ?>: <span id="thumbsniper_scaling_default"></span>)
			</td>
		</tr>

<?php
	}



	function thumbsniper_background()
	{
		$option = $this->get_general_setting('thumbsniper_background');
?>

		<tr>
			<td>
				<label for="thumbsniper_general_settings[thumbsniper_background]">
					<?php echo __("PopUp style", "thumbsniper"); ?>
				</label>
			</td>
			<td>
				<select id="thumbsniper_background" name="thumbsniper_general_settings[thumbsniper_background]">
					<option value="blue"<?php if ($option == 'blue') echo(' selected=selected'); ?>>blue</option>
					<option value="red"<?php if ($option == 'red') echo(' selected=selected'); ?>>red</option>
					<option value="green"<?php if ($option == 'green') echo(' selected=selected'); ?>>green</option>
					<option value="light"<?php if ($option == 'light') echo(' selected=selected'); ?>>light</option>
					<option value="dark"<?php if ($option == 'dark') echo(' selected=selected'); ?>>dark</option>
					<option value="cream"<?php if ($option == 'cream') echo(' selected=selected'); ?>>cream</option>
					<option value="youtube"<?php if ($option == 'youtube') echo(' selected=selected'); ?>>youtube</option>
					<option value="jtools"<?php if ($option == 'jtools') echo(' selected=selected'); ?>>jtools</option>
					<option value="cluetip"<?php if ($option == 'cluetip') echo(' selected=selected'); ?>>cluetip</option>
					<option value="tipped"<?php if ($option == 'tipped') echo(' selected=selected'); ?>>tipped</option>
					<option value="tipsy"<?php if ($option == 'tipsy') echo(' selected=selected'); ?>>tipsy</option>
				</select> (<?php _e('default', 'thumbsniper'); ?>: <?php echo $this->general_settings_defaults['thumbsniper_background']; ?>)
			</td>
		</tr>

<?php
	}



	function thumbsniper_position()
	{
		$option = $this->get_general_setting('thumbsniper_position');
?>

		<tr>
			<td>
				<label for="thumbsniper_general_settings[thumbsniper_position]">
					<?php echo __("Position", "thumbsniper"); ?>
				</label>
			</td>
			<td>
				<select id="thumbsniper_position" name="thumbsniper_general_settings[thumbsniper_position]">
					<option value="above"<?php if ($option == 'above') echo(' selected=selected'); ?>><?php _e('above', 'thumbsniper'); ?></option>
					<option value="below"<?php if ($option == 'below') echo(' selected=selected'); ?>><?php _e('below', 'thumbsniper'); ?></option>
					<option value="left"<?php if ($option == 'left') echo(' selected=selected'); ?>><?php _e('left', 'thumbsniper'); ?></option>
					<option value="right"<?php if ($option == 'right') echo(' selected=selected'); ?>><?php _e('right', 'thumbsniper'); ?></option>
				</select> (<?php _e('default', 'thumbsniper'); ?>: <?php _e($this->general_settings_defaults['thumbsniper_position'], 'thumbsniper'); ?>)
			</td>
		</tr>

<?php
	}



	function thumbsniper_wp_jquery()
	{
		$option = $this->get_general_setting('thumbsniper_wp_jquery');
?>

		<tr>
			<td>
				<label for="thumbsniper_general_settings[thumbsniper_wp_jquery]">
					<?php echo __("use default wordpress jquery", "thumbsniper"); ?>
				</label>
			</td>
			<td>
				<select id="thumbsniper_wp_jquery" name="thumbsniper_general_settings[thumbsniper_wp_jquery]">
					<option value="yes"<?php if ($option == 'yes') echo(' selected=selected'); ?>><?php _e('yes', 'thumbsniper'); ?></option>
					<option value="no"<?php if ($option == 'no') echo(' selected=selected'); ?>><?php _e('no', 'thumbsniper'); ?></option>
				</select> (<?php _e('default', 'thumbsniper'); ?>: <?php _e($this->general_settings_defaults['thumbsniper_wp_jquery'], 'thumbsniper'); ?>)
			</td>
		</tr>

<?php
	}



	function thumbsniper_jquery_noconflict()
	{
		$option = $this->get_general_setting('thumbsniper_jquery_noconflict');
?>

		<tr>
			<td>
				<label for="thumbsniper_general_settings[thumbsniper_jquery_noconflict]">
					<?php echo __("use jquery's noConflict mode", "thumbsniper"); ?>
				</label>
			</td>
			<td>
				<select id="thumbsniper_jquery_noconflict" name="thumbsniper_general_settings[thumbsniper_jquery_noconflict]">
					<option value="yes"<?php if ($option == 'yes') echo(' selected=selected'); ?>><?php _e('yes', 'thumbsniper'); ?></option>
					<option value="no"<?php if ($option == 'no') echo(' selected=selected'); ?>><?php _e('no', 'thumbsniper'); ?></option>
				</select> (<?php _e('default', 'thumbsniper'); ?>: <?php _e($this->general_settings_defaults['thumbsniper_jquery_noconflict'], 'thumbsniper'); ?>)
			</td>
		</tr>

<?php
	}



        function thumbsniper_qtip_footer()
        {
                $option = $this->get_general_setting('thumbsniper_qtip_footer');
?>

                <tr>
                        <td>
                                <label for="thumbsniper_general_settings[thumbsniper_qtip_footer]">
                                        <?php echo __("load qTip-library in page footer", "thumbsniper"); ?>
                                </label>
                        </td>
                        <td>
                                <select id="thumbsniper_qtip_footer" name="thumbsniper_general_settings[thumbsniper_qtip_footer]">
                                        <option value="yes"<?php if ($option == 'yes') echo(' selected=selected'); ?>><?php _e('yes', 'thumbsniper'); ?></option>
                                        <option value="no"<?php if ($option == 'no') echo(' selected=selected'); ?>><?php _e('no', 'thumbsniper'); ?></option>
                                </select> (<?php _e('default', 'thumbsniper'); ?>: <?php _e($this->general_settings_defaults['thumbsniper_qtip_footer'], 'thumbsniper'); ?>)
                        </td>
                </tr>

<?php
        }



	function thumbsniper_showfooter()
	{
		$option = $this->get_general_setting('thumbsniper_showfooter');
?>

		<tr>
			<td>
				<label for="thumbsniper_general_settings[thumbsniper_showfooter]">
					<?php echo __("admit a footer link", "thumbsniper"); ?>
				</label>
			</td>
			<td>
				<select id="thumbsniper_showfooter" name="thumbsniper_general_settings[thumbsniper_showfooter]">
					<option value="yes"<?php if ($option == 'yes') echo(' selected=selected'); ?>><?php _e('yes', 'thumbsniper'); ?></option>
					<option value="no"<?php if ($option == 'no') echo(' selected=selected'); ?>><?php _e('no', 'thumbsniper'); ?></option>
				</select>
			</td>
		</tr>

<?php
	}



	function thumbsniper_variant()
	{
		$option = $this->get_general_setting('thumbsniper_variant');

		$variants = array();
		$variants[0] = "plain";
		$variants[1] = "fadeLeftToRight";
		$variants[2] = "fadeRightToLeft";
?>

		<tr>
			<td>
				<label for="thumbsniper_general_settings[thumbsniper_variant]">
					<?php echo __("thumbnail variant", "thumbsniper"); ?>
				</label>
			</td>
			<td>
				<select id="thumbsniper_variant" name="thumbsniper_general_settings[thumbsniper_variant]" onchange="thumbsniper_set_scaling_options(this.options[this.selectedIndex].value);">

<?php
	foreach($variants as $key => $value) 
	{
		$out = '<option value="' . $key .'"';
		if ($key == $option)
		{
			$out.= ' selected=selected';
		}
		$out.= '>' . $value . '</option>';
		echo $out;
	}
?>
				</select> (<?php _e('default', 'thumbsniper'); ?>: <?php echo $variants[$this->get_general_settings_defaults("thumbsniper_variant")]; ?>)
			</td>
		</tr>

<?php
	}



	function general_settings_validate($input)
	{
		$valid = array();

		if( in_array( $input['thumbsniper_preview'], array( "all", "external", "marked" ) ) )
		{
			$valid['thumbsniper_preview'] = $input['thumbsniper_preview'];
		}


		// EXCLUDE URLS

		$urls = convert_line_breaks( $input['thumbsniper_exclude_urls'], ";" );
		$urls = preg_split( "/;/", $urls );
		$newurls = array();

		foreach( $urls as $url )
		{
			if( $url == "" )
			{
				continue;
			}
			$newurls[] = $url;
		}

		$valid['thumbsniper_exclude_urls'] = $newurls;


		// INCLUDE PAGES

		$pages = $input['thumbsniper_include_pages'];
		$pages = preg_split( "/,/", $pages );
		$pageIds = array();

		foreach( $pages as $page )
		{
			if(is_numeric($page))
			{
				$pageIds[] = $page;
			} 
		}

		$valid['thumbsniper_include_pages'] = $pageIds;


		if( in_array( $input['thumbsniper_scaling'], array( "2", "3", "4", "5", "6", "7", "8" ) ) )
		{
			$valid['thumbsniper_scaling'] = $input['thumbsniper_scaling'];
		}

		if( in_array( $input['thumbsniper_background'], array( "blue", "red", "green", "light", "dark", "cream", "youtube", "jtools", "cluetip", "tipped", "tipsy" ) ) )
		{
			$valid['thumbsniper_background'] = $input['thumbsniper_background'];
		}

		if( in_array( $input['thumbsniper_position'], array( "above", "below", "left", "right" ) ) )
		{
			$valid['thumbsniper_position'] = $input['thumbsniper_position'];
		}

		if( in_array( $input['thumbsniper_wp_jquery'], array( "yes", "no" ) ) )
		{
			$valid['thumbsniper_wp_jquery'] = $input['thumbsniper_wp_jquery'];
		}

		if( in_array( $input['thumbsniper_jquery_noconflict'], array("yes", "no" ) ) )
		{
			$valid['thumbsniper_jquery_noconflict'] = $input['thumbsniper_jquery_noconflict'];
		}

                if( in_array( $input['thumbsniper_qtip_footer'], array("yes", "no" ) ) )
                {
                        $valid['thumbsniper_qtip_footer'] = $input['thumbsniper_qtip_footer'];
                }

		if( in_array( $input['thumbsniper_showfooter'], array("yes", "no" ) ) )
		{
			$valid['thumbsniper_showfooter'] = $input['thumbsniper_showfooter'];
		}

		if( in_array( $input['thumbsniper_variant'], array( "0", "1", "2" ) ) )
		{
			$valid['thumbsniper_variant'] = $input['thumbsniper_variant'];
		}

		return $valid;
	}



	function dummy()
	{
		// does nothing
	}



	function set_general_settings_defaults($key, $value)
	{
		if( !is_array($this->general_settings_defaults) )
		{
			$this->general_settings_defaults = array();
		}

		$this->general_settings_defaults[$key] = $value;
	}



	function get_general_settings_defaults($key)
	{
		return $this->general_settings_defaults[$key];
	}



	function get_image_size()
	{
		$imageWidth = 1;
		$imageHeight = 1;

		switch( $this->get_general_setting( "thumbsniper_scaling" ) )
		{
			case "2":
				$imageWidth = 365;
				switch( $this->get_general_setting( "thumbsniper_variant" ) )
				{
					case 0:
						$imageHeight = 274;
						break;
					case 1:
						$imageHeight = 461;
						break;
					case 2:
						$imageHeight = 461;
						break;
				} //switch
				break;
			case "3":
				$imageWidth = 242;
				switch( $this->get_general_setting( "thumbsniper_variant" ) )
				{
					case 0:
						$imageHeight = 182;
						break;
					case 1:
						$imageHeight = 306;
						break;
					case 2:
						$imageHeight = 306;
						break;
				} //switch
				break;
			case "4":
				$imageWidth = 182;
				switch( $this->get_general_setting( "thumbsniper_variant" ) )
				{
					case 0:
						$imageHeight = 137;
						break;
					case 1:
						$imageHeight = 230;
						break;
					case 2:
						$imageHeight = 230;
						break;
				} //switch
				break;
			case "5":
				$imageWidth = 146;
				switch( $this->get_general_setting( "thumbsniper_variant" ) )
				{
					case 0:
						$imageHeight = 110;
						break;
					case 1:
						$imageHeight = 184;
						break;
					case 2:
						$imageHeight = 184;
						break;
				} //switch
				break;
			case "6":
				$imageWidth = 121;
				switch( $this->get_general_setting( "thumbsniper_variant" ) )
				{
					case 0:
						$imageHeight = 91;
						break;
					case 1:
						$imageHeight = 153;
						break;
					case 2:
						$imageHeight = 153;
						break;
				} //switch
				break;
			case "7":
				$imageWidth = 104;
				switch( $this->get_general_setting( "thumbsniper_variant" ) )
				{
					case 0:
						$imageHeight = 78;
						break;
					case 1:
						$imageHeight = 131;
						break;
					case 2:
						$imageHeight = 131;
						break;
				} //switch
				break;
			case "8":
				$imageWidth = 91;
				switch( $this->get_general_setting( "thumbsniper_variant" ) )
				{
					case 0:
						$imageHeight = 68;
						break;
					case 1:
						$imageHeight = 115;
						break;
					case 2:
						$imageHeight = 115;
						break;
				} //switch
				break;
		} //switch

		$size = array();
		$size['w'] = $imageWidth;
		$size['h'] = $imageHeight;

		return $size;
	} //function

} // class

?>
